YARP 3.3.1 (2020-01-17)                                                {#v3_3_1}
=======================

[TOC]

YARP 3.3.1 Release Notes
========================


A (partial) list of bug fixed and issues resolved in this release can be found
[here](https://github.com/robotology/yarp/issues?q=label%3A%22Fixed+in%3A+YARP+v3.3.1%22).


Important Changes
-----------------

### Dependencies

- OpenCV 4 is now supported.


Bug Fixes
---------

### Libraries

#### YARP_dev

* Fixed missing header for deprecation warning macro.


### Devices

#### grabberDual

* Fixed the double open issue. (#2121)


### Tools

#### yarpdataplayer

* Fixed the part-port mismatch due to bad sorting. (#2173)
* Fixed the clock drifting when the player was paused for long time. (#2139)
* Fixed the rpc request `play` while it is already running. (#2144)


### Bindings

#### Perl

* The RPATH for installed perl bindings is now correct.


Contributors
------------

This is a list of people that contributed to this release (generated from the
git history using `git shortlog -ens --no-merges v3.3.0..v3.3.1`):

```
    16	Nicolò Genesio <nicolo.genesio@iit.it>
     6	Daniele E. Domenichelli <daniele.domenichelli@iit.it>
     1	Bartek Łukawski <bwmn.peter@gmail.com>
```
